# CHANGELOG


## v1.9.0 (2024-12-27)

### Build System

- Add .mypy_cache to .gitignore
  ([`e418e77`](https://github.com/OZI-Project/OZI.build/commit/e418e77dc8937d68624e725f889c2ed0b732b4bb))

Signed-off-by: rjdbcm <rjdbcm@outlook.com>

- Add release branches to workflow
  ([`39e1d7e`](https://github.com/OZI-Project/OZI.build/commit/39e1d7e810401d856db8f7d6376a01854bbc2826))

Signed-off-by: Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>

- Correct artifact name
  ([`731e5fd`](https://github.com/OZI-Project/OZI.build/commit/731e5fd345a231c1b82df5bcb4430fc418cc0fe7))

Signed-off-by: rjdbcm <rjdbcm@outlook.com>

- Correct name
  ([`c20e4b2`](https://github.com/OZI-Project/OZI.build/commit/c20e4b215100fc362665c69428b7a0f744b65da4))

Signed-off-by: rjdbcm <rjdbcm@outlook.com>

- Fix changelog
  ([`950537f`](https://github.com/OZI-Project/OZI.build/commit/950537f1cebfb52f3fafd5b21b9cb274fb604f56))

Signed-off-by: rjdbcm <rjdbcm@outlook.com>

- Fix dist checkpoint
  ([`4dd9149`](https://github.com/OZI-Project/OZI.build/commit/4dd91499c3f354e25c99f9ccaa5e38da1936f945))

Signed-off-by: rjdbcm <rjdbcm@outlook.com>

- Fix file permissions
  ([`107a6ed`](https://github.com/OZI-Project/OZI.build/commit/107a6ed2e92f4630e450c9ffcedbb95698baa409))

Signed-off-by: rjdbcm <rjdbcm@outlook.com>

- Fix release workflow
  ([`3b4a58e`](https://github.com/OZI-Project/OZI.build/commit/3b4a58e2ecf7d8fb8685c92d514d44c47acb07c9))

Signed-off-by: rjdbcm <rjdbcm@outlook.com>

- Fix wheel release
  ([`eb02a41`](https://github.com/OZI-Project/OZI.build/commit/eb02a41c4c914b6007df54323c0dec2e783ed865))

Signed-off-by: rjdbcm <rjdbcm@outlook.com>

- Fix workflow
  ([`877ca93`](https://github.com/OZI-Project/OZI.build/commit/877ca937ce8481634d35940b9936690ad52d89df))

Signed-off-by: rjdbcm <rjdbcm@outlook.com>

- Main is a release branch
  ([`9c2f19b`](https://github.com/OZI-Project/OZI.build/commit/9c2f19b9ad85cc63bcbdb01ee1ef3c71838e6908))

Signed-off-by: rjdbcm <rjdbcm@outlook.com>

- No tests for now
  ([`00af619`](https://github.com/OZI-Project/OZI.build/commit/00af619cfd2d33026531e2dd0085560356e6bd5b))

Signed-off-by: Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>

- Remove master release branch pattern
  ([`f96d21a`](https://github.com/OZI-Project/OZI.build/commit/f96d21af1b5fecfc121490f5c2b7d06374e6a932))

Signed-off-by: rjdbcm <rjdbcm@outlook.com>

- Run black
  ([`153735b`](https://github.com/OZI-Project/OZI.build/commit/153735b18c4f6a3a9419a7555009980c35bb0bdc))

Signed-off-by: rjdbcm <rjdbcm@outlook.com>

- Run isort
  ([`0fb8ecf`](https://github.com/OZI-Project/OZI.build/commit/0fb8ecf36e1025822d661deb60c816888ec36f1f))

Signed-off-by: rjdbcm <rjdbcm@outlook.com>

- Shorter custom workflow
  ([`cd8fd46`](https://github.com/OZI-Project/OZI.build/commit/cd8fd46c9fc5d7eec73ab127fd7bd1cd3586afe7))

Signed-off-by: rjdbcm <rjdbcm@outlook.com>

- Skip dist checkpoint
  ([`6a3a5e2`](https://github.com/OZI-Project/OZI.build/commit/6a3a5e2736587dabfd7fbe581881a7253a4c3d23))

Signed-off-by: Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>

- Use a custom workflow
  ([`0167fd2`](https://github.com/OZI-Project/OZI.build/commit/0167fd20891af2b51b5966aa017e39a2e38c050e))

Signed-off-by: rjdbcm <rjdbcm@outlook.com>

- Use trusted publishing and dogfood OZI
  ([`4268b0d`](https://github.com/OZI-Project/OZI.build/commit/4268b0db89ebbc1c2609c66a7ab93f8f0f069a10))

Signed-off-by: rjdbcm <rjdbcm@outlook.com>

### Features

- Use OZI for publishing
  ([`485bd37`](https://github.com/OZI-Project/OZI.build/commit/485bd37accff05383ca5ce509f5331129eb5baa7))

Feat/dogfood ozi


## v1.8.3 (2024-12-23)


## v1.8.2 (2024-12-19)


## v1.8.1 (2024-12-11)


## v1.8.0 (2024-12-09)


## v1.7.2 (2024-12-05)


## v1.7.1 (2024-12-02)


## v1.7.0 (2024-12-02)


## v1.6.1 (2024-10-27)


## v1.5.1 (2024-09-04)


## v1.5.0 (2024-09-01)


## v1.4.3 (2024-08-28)


## v1.4.2 (2024-08-28)


## v1.4.1 (2024-08-28)


## v1.4.0 (2024-08-28)


## v1.3.2 (2024-08-26)


## v1.3.1 (2024-08-26)


## v1.3.0 (2024-08-26)

### Bug Fixes

- ``project.optional_dependencies`` is parsed into wheel METADATA
  ([`6933ce8`](https://github.com/OZI-Project/OZI.build/commit/6933ce8397bffd293ad07ae9b4c95ce01da765a1))

Signed-off-by: rjdbcm <rjdbcm@outlook.com>

- Warn for ignoring nested keys
  ([`1b6e088`](https://github.com/OZI-Project/OZI.build/commit/1b6e088a1fcd23191cd3f4ca23ac826426d4b65a))

- Warn for ignoring nested keys
  ([`d7a8d7e`](https://github.com/OZI-Project/OZI.build/commit/d7a8d7e2740a6dd60ba5fcf401d36dc740312d93))

Signed-off-by: rjdbcm <rjdbcm@outlook.com>


## v1.0.2 (2024-08-10)


## v1.0.1 (2024-08-09)


## v1.0.0 (2024-08-06)


## v0.0.18 (2024-05-11)


## v0.0.17 (2024-05-11)


## v0.0.16 (2024-05-11)


## v0.0.15 (2024-05-04)


## v0.0.14 (2024-05-04)


## v0.0.12 (2024-05-03)


## v0.0.11 (2024-05-03)


## v0.0.10 (2024-05-03)


## v0.0.9 (2024-05-02)


## v0.0.6 (2024-05-01)


## v0.0.5 (2024-05-01)


## v0.0.4 (2024-05-01)


## v0.0.3 (2024-04-30)


## v0.0.2 (2024-04-30)

### Continuous Integration

- Update to debian buster
  ([`cc0b0c0`](https://github.com/OZI-Project/OZI.build/commit/cc0b0c01163730aecd6fc938120789a343269460))


## v0.1.9999996 (2020-07-15)
